@@ -212,9 +212,11 @@ display_about_dialog (GtkAction       *action,
                 "comments", _("Window Picker"),
                 "version", PACKAGE_VERSION,
                 "authors", close_window_authors,
+                "icon-name", "preferences-system-windows",
                 "logo-icon-name", "preferences-system-windows",
                 "copyright", "Copyright \xc2\xa9 2008 Canonical Ltd\n"
-                             "Copyright \xc2\xa9 2013-2014 Stefano Karapetsas",
+                             "Copyright \xc2\xa9 2013-2014 Stefano Karapetsas\n"
+                             "Copyright \xc2\xa9 2015-2017 MATE developers",
                 NULL);
 
   gtk_widget_show (panel_about_dialog);
@@ -243,6 +245,7 @@ display_prefs_dialog (GtkAction       *action,
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), _("Preferences"));
+  gtk_window_set_icon_name (GTK_WINDOW (window), "preferences-system-windows");
   gtk_window_set_type_hint (GTK_WINDOW (window),
                             GDK_WINDOW_TYPE_HINT_DIALOG);
   gtk_container_set_border_width (GTK_CONTAINER (window), 12);
@@ -271,7 +274,7 @@ display_prefs_dialog (GtkAction       *action,
   gtk_widget_set_size_request (nb, -1, 100);
   
   hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
-  gtk_box_pack_start (GTK_BOX (box), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start (GTK_BOX (box), hbox, FALSE, FALSE, 0);
   
   label = gtk_label_new (" ");
   gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 0);
